@@ -141,13 +141,15 @@ gpm_button_grab_keystring (GpmButton *button, guint64 keycode)
 {
 	guint modmask = AnyModifier;
 	Display *display;
+	GdkDisplay *gdkdisplay;
 	gint ret;
 
 	/* get the current X Display */
 	display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default());
 
 	/* don't abort on error */
-	gdk_error_trap_push ();
+	gdkdisplay = gdk_display_get_default ();
+	gdk_x11_display_error_trap_push (gdkdisplay);
 
 	/* grab the key if possible */
 	ret = XGrabKey (display, keycode, modmask,
@@ -170,8 +172,8 @@ gpm_button_grab_keystring (GpmButton *button, guint64 keycode)
 	}
 
 	/* we are not processing the error */
-	gdk_flush ();
-	gdk_error_trap_pop_ignored ();
+	gdk_display_flush (gdkdisplay);
+	gdk_x11_display_error_trap_pop_ignored (gdkdisplay);
 
 	egg_debug ("Grabbed modmask=%x, keycode=%li", modmask, (long int) keycode);
 	return TRUE;
@@ -376,23 +378,18 @@ gpm_button_init (GpmButton *button)
 #endif
 	/* register the brightness keys */
 	gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
-#ifdef HAVE_XF86XK_SUSPEND
+
 	/* The kernel messes up suspend/hibernate in some places. One of
 	 * them is the key names. Unfortunately, they refuse to see the
 	 * errors of their way in the name of 'compatibility'. Meh
 	 */
 	gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_HIBERNATE);
-#endif
 	gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
-#ifdef HAVE_XF86XK_HIBERNATE
 	gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
-#endif
 	gpm_button_xevent_key (button, XF86XK_MonBrightnessUp, GPM_BUTTON_BRIGHT_UP);
 	gpm_button_xevent_key (button, XF86XK_MonBrightnessDown, GPM_BUTTON_BRIGHT_DOWN);
 	gpm_button_xevent_key (button, XF86XK_ScreenSaver, GPM_BUTTON_LOCK);
-#ifdef HAVE_XF86XK_BATTERY
 	gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
-#endif
 	gpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, GPM_BUTTON_KBD_BRIGHT_UP);
 	gpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, GPM_BUTTON_KBD_BRIGHT_DOWN);
 	gpm_button_xevent_key (button, XF86XK_KbdLightOnOff, GPM_BUTTON_KBD_BRIGHT_TOGGLE);
